<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "Du m&aring;ste infoga pristyp"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "Du m&aring;ste fortfarande infoga pris f&ouml;r"; break;
case "per la settimana dal":  			$messaggio = "f&ouml;r veckan fr&aring;n"; break;
case "per il giorno dal":  			$messaggio = "f&ouml;r dagen fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "La settimana dal":  			$messaggio = "Veckan fr&aring;n"; break;
case "Il giorno dal":  				$messaggio = "Dagen fr&aring;n"; break;
case "è piena":  				$messaggio = "&auml;r fullbokad"; break;
case "è pieno":  				$messaggio = "&auml;r fullbokad"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "Antalet veckor med den veckoliga extrakostnaden nummer"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "Antalet dagar med den dagliga extrakostnaden nummer"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "&auml;r fler &auml;n antalet reserverade veckor"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "&auml;r fler &auml;n antalet reserverade dagar"; break;
case "persone":  				$messaggio = "personer"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "Minst en period med &ouml;verl&aring;telseregel 1 m&aring;ste vara upptagen"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "R&ouml;relser som m&aring;ste g&ouml;ras i perioder med  <div style=\"display: inline; color: blue;\">&ouml;verl&aring;telseregel 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "R&ouml;relser som har gjorts i perioder med <div style=\"display: inline; color: blue;\">&ouml;verl&aring;telseregel 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "Reservationen fr&aring;n"; break;
case "a nome di":  				$messaggio = "f&ouml;r herr/fru"; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "Kan inte forts&auml;tta d&aring; reservationstabellen har &auml;ndrats under tiden"; break;
case "Continua lo stesso":  			$messaggio = "Forts&auml;tt &auml;nd&aring;"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Non esistono clienti chiamati":  		$messaggio = "Det finns inga kunder med namn"; break;
case "nel database":  				$messaggio = "i databasen"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "L&auml;gg till data f&ouml;r en ny kund"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "Det finns redan kunder med samma eller liknande efternamn"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "Det finns redan kunder med samma eller liknande efternamn och f&ouml;rnamn"; break;
case "nato il":	  				$messaggio = "f&ouml;dd"; break;
case "nata il":	  				$messaggio = "f&ouml;dd"; break;
case "CAP":  					$messaggio = "postnummer"; break;
case "Telefono":  				$messaggio = "telefonnummer"; break;
case "2º telefono":  				$messaggio = "andra telefonnummer"; break;
case "3º telefono":  				$messaggio = "tredje telefonnummer"; break;
case "Utilizza il cliente":  			$messaggio = "Anv&auml;nd kund"; break;
case "per la prenotazione":  			$messaggio = "f&ouml;r reservationen"; break;
case "Modifica i dati del cliente":  		$messaggio = "&Auml;ndra kunddata"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "L&auml;gg till en ny kund"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Kundens efternamn beh&ouml;vs"; break;
case "I dati del cliente":  			$messaggio = "Kunddata f&ouml;r kund"; break;
case "sono stati inseriti":  			$messaggio = "har lagts till"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "L&auml;gg till eller &auml;ndra en kunds data"; break;
case "Cognome":  				$messaggio = "Efternamn"; break;
case "nome":  					$messaggio = "f&ouml;rnamn"; break;
case "sesso":  					$messaggio = "k&ouml;n"; break;
case "Data di nascita":  			$messaggio = "F&ouml;delsedatum"; break;
case "anno con 4 cifre":  			$messaggio = "&aring;r med fyra siffror"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "città":  					$messaggio = "stad"; break;
case "Via":  					$messaggio = "Gata"; break;
case "Piazza":  				$messaggio = "Torg"; break;
case "Viale":  					$messaggio = "Aveny"; break;
case "Vicolo":  				$messaggio = "V&auml;g"; break;
case "Numero di telefono":  			$messaggio = "Telefonnummer"; break;
case "Secondo telefono":  			$messaggio = "Andra telefon"; break;
case "Terzo telefono":  			$messaggio = "Tredje telefon"; break;
case "Numero di fax":  				$messaggio = "Faxnummer"; break;
case "Seconda persona di riferimento":  	$messaggio = "Andra referensperson"; break;
case "Inserisci i dati":  			$messaggio = "L&auml;gg till data"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "Italia":  				$messaggio = ""; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "data specifik f&ouml;r de 2 referenspersonerna kommer inte &auml;ndras"; break;
case "sono stati modificati":  			$messaggio = "har &auml;ndrats"; break;
case "e":  					$messaggio = "och"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "Antalet reservationer &auml;r felaktigt"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Antal typer att till&auml;gga"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "Det finns inga kunder med namn"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Det finns inga perioder i &ouml;verl&aring;telseregel 1 f&ouml;r vilka det &auml;r till&aring;tet att l&auml;gga till reservationer f&ouml;r anv&auml;ndare"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "Antalet personer &auml;r felaktigt"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Data fr&aring;n och extrakostnader &auml;r felaktiga"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "Du kan inte l&auml;gga till mer &auml;n en extrakostnad med procentandel f&ouml;r det totala priset per reservation"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "Extrakostnaden"; break;
case "in questo periodo":  			$messaggio = "kan inte infogas i den h&auml;r perioden"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "V&auml;lj veckorna som extrakostnaden ska till&auml;mpas f&ouml;r"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "V&auml;lj dagarna som extrakostnaden ska till&auml;mpas"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Non si possono inserire altri costi":  	$messaggio = "Du kan inte l&auml;gga till fler kostnader"; break;
case "in questo periodo, già":  		$messaggio = "i den h&auml;r perioden, redan"; break;
case "presenti":  				$messaggio = "n&auml;rvarande"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Antalet personer m&aring;ste anges f&ouml;r extrakostnaden"; break;
case "Il costo aggiuntivo":  			$messaggio = "Extrakostnaden"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "&auml;r inkompatibelt med valt pris"; break;
case "non può essere applicato":  		$messaggio = "kan inte till&auml;mpas"; break;
case "Documento":  				$messaggio = "Dokument"; break;
case "scadenza":  				$messaggio = "upph&ouml;rande"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Tillbaka till kundtill&auml;ggning"; break;
case "Annulla":  				$messaggio = "Avbryt"; break;
case "Ospite della prenotazione":  		$messaggio = "Reservationsg&auml;st"; break;
case "tipologia":  				$messaggio = "typ"; break;
case "Ospiti della prenotazione":  		$messaggio = "Reservationsg&auml;ster"; break;
case "Altri ospiti":  				$messaggio = "Andra g&auml;ster"; break;
case "nato":  					$messaggio = "f&ouml;dd"; break;
case "nata":  					$messaggio = "f&ouml;dd"; break;
case "il":  					$messaggio = "den"; break;
case " a":  					$messaggio = " i"; break;
case "scade":  					$messaggio = "upph&ouml;r"; break;
case "cittadinanza":  				$messaggio = "nationalitet"; break;
case "città di nascita":  			$messaggio = "f&ouml;delsedatum"; break;
case "reg./prov. di nascita":  			$messaggio = "f&ouml;delseregion"; break;
case "nazione di nascita":  			$messaggio = "f&ouml;delseland"; break;
case "Residenza":  				$messaggio = "Hemvist"; break;
case "nazione":  				$messaggio = "land"; break;
case "rilasciato da":  				$messaggio = "utf&auml;rdat av"; break;
case "nazione di rilascio":  			$messaggio = "utf&auml;rdande land"; break;
case "parentela":  				$messaggio = "sl&auml;ktskap"; break;
case "Codice fiscale":  			$messaggio = "skattekod"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "med valda extrakostnader"; break;
case "I beni richiesti dal costo":  		$messaggio = "Varor som beh&ouml;vs f&ouml;r kostnaden"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "&auml;r inte tillg&auml;ngliga i inventariet"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Clienti":  				$messaggio = "Clients"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "regione":  				$messaggio = "region"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "The number of people must be inserted for this rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "lo sconto è sbagliato":  			$messaggio = "the discount is wrong"; break;
case "la caparra è sbagliata":  		$messaggio = "the deposit is wrong"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "le commissioni sono sbagliate":  		$messaggio = "commissions are wrong"; break;
case "lingua":  				$messaggio = "language"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "You must insert at least one person that can be main guest"; break;
case "non si sono potuti usare":  		$messaggio = "It was not possible to use"; break;
case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "extra beds as there was no people type with that number"; break;
case "E-mail":  				$messaggio = "E-mail"; break;
case "Seconda e-mail":  			$messaggio = "Second e-mail"; break;
case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "Certified e-mail"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "Per questa tariffa si deve inserire un numero minimo di":	$messaggio = "For this rate you have to insert at least"; break;
case "persona":  				$messaggio = "person"; break;
case "Usa il cliente della prenotazione originale":	$messaggio = "Use the client from the original reservation"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>